@@ -4,9 +4,10 @@
 #' Read all Veeco ascii files in a given folder. It searches for all files containing a 
 #' given patter (".txt" by default) and uses the \code{afmReadVeeco} function.
 #'
-#' @usage afmReadVeecoFolder(folder, pattern = ".txt")
+#' @usage afmReadVeecoFolder(folder, pattern = ".txt", ...)
 #' @param folder Name of the  folder containing the Veeco files.
 #' @param pattern Pattern that will identify the Veeco files (".txt" by default).
+#' @param ... Parameters to be passed to the afmReadVeeco() function.
 
 #' @return An \code{afmexperiment} class data structure with all F-d curves. 
 #'
@@ -17,10 +18,10 @@
 #' @export
 #' 
 
-afmReadVeecoFolder <- function(folder, pattern = ".txt"){
+afmReadVeecoFolder <- function(folder, pattern = ".txt",...){
   if (dir.exists(folder)){
     dataFiles <- list.files(folder, pattern = pattern, full.names = FALSE)
-    data <- lapply(dataFiles, afmReadVeeco, path = folder)
+    data <- lapply(dataFiles, afmReadVeeco, path = folder,...)
     names(data) <- dataFiles
     return(afmexperiment(data))
   }else{
